changeset 23781:276858bc6ac6

recast "JVMCI flags" language to "JVMCI system properties"
author Doug Simon <doug.simon@oracle.com>
date Wed, 05 Oct 2016 17:30:21 +0200
parents 4ae76f509448
children 286dce1eca9b
files jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java
diffstat 2 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java	Wed Oct 05 16:28:05 2016 +0200
+++ b/jvmci/jdk.vm.ci.hotspot/src/jdk/vm/ci/hotspot/HotSpotJVMCIRuntime.java	Wed Oct 05 17:30:21 2016 +0200
@@ -174,11 +174,11 @@
         }
 
         /**
-         * Prints all option flags to {@code out}.
+         * Prints system properties used to configure shared JVMCI code.
          *
          * @param out stream to print to
          */
-        public static void printFlags(PrintStream out) {
+        public static void printSystemProperties(PrintStream out) {
             out.println("[JVMCI system properties]");
             int typeWidth = 0;
             int nameWidth = 0;
@@ -311,8 +311,8 @@
 
         if (config.getFlag("JVMCIPrintSystemProperties", Boolean.class)) {
             PrintStream out = new PrintStream(getLogStream());
-            Option.printFlags(out);
-            compilerFactory.printFlags(out);
+            Option.printSystemProperties(out);
+            compilerFactory.printSystemProperties(out);
         }
 
         if (Option.PrintConfig.getBoolean()) {
--- a/jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java	Wed Oct 05 16:28:05 2016 +0200
+++ b/jvmci/jdk.vm.ci.runtime/src/jdk/vm/ci/runtime/services/JVMCICompilerFactory.java	Wed Oct 05 17:30:21 2016 +0200
@@ -74,10 +74,10 @@
     public abstract JVMCICompiler createCompiler(JVMCIRuntime runtime);
 
     /**
      * Prints a help message describing the flags supported by this compiler and how to set them.
      *
      * @param out where to print the message
      */
-    public void printFlags(PrintStream out) {
+    public void printSystemProperties(PrintStream out) {
     }
 }
@@ -74,10 +74,10 @@
 
     /**
-     * Prints a help message describing the flags supported by this compiler and how to set them.
+     * Prints a help message describing the system properties used to configure this compiler.
      *
      * @param out where to print the message